==> haskell-cryptohash-0.11.9-345-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash
version:              0.11.9
visibility:           public
id:                   cryptohash-0.11.9-K3a0fAHAiu2FHFicuGM3MM
key:                  cryptohash-0.11.9-K3a0fAHAiu2FHFicuGM3MM
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-cryptohash
synopsis:             collection of crypto hashes, fast, pure and practical
description:
    DEPRECATED: this library is still fully functional, but please use cryptonite for new projects
    and convert old one to use cryptonite. This is where things are at nowadays.

    A collection of crypto hashes, with a practical incremental and one-pass, pure APIs,
    with performance close to the fastest implementations available in other languages.

    The implementations are made in C with a haskell FFI wrapper that hide the C implementation.

    Simple examples using the unified API:

    > import Crypto.Hash
    >
    > sha1 :: ByteString -> Digest SHA1
    > sha1 = hash
    >
    > hexSha3_512 :: ByteString -> String
    > hexSha3_512 bs = show (hash bs :: Digest SHA3_512)

    Simple examples using the module API:

    > import qualified Crypto.Hash.SHA1 as SHA1
    >
    > main = putStrLn $ show $ SHA1.hash (Data.ByteString.pack [0..255])

    > import qualified Crypto.Hash.SHA3 as SHA3
    >
    > main = putStrLn $ show $ digest
    >   where digest = SHA3.finalize ctx
    >         ctx    = foldl'\'' SHA3.update iCtx (map Data.ByteString.pack [ [1,2,3], [4,5,6] ]
    >         iCtx   = SHA3.init 224

category:             Data, Cryptography
abi:                  8739b0f62895a2e668b4901fb0ae95cd
exposed:              True
exposed-modules:
    Crypto.Hash Crypto.Hash.MD2 Crypto.Hash.MD4 Crypto.Hash.MD5
    Crypto.Hash.RIPEMD160 Crypto.Hash.SHA1 Crypto.Hash.SHA224
    Crypto.Hash.SHA256 Crypto.Hash.SHA3 Crypto.Hash.SHA384
    Crypto.Hash.SHA512 Crypto.Hash.SHA512t Crypto.Hash.Skein256
    Crypto.Hash.Skein512 Crypto.Hash.Tiger Crypto.Hash.Types
    Crypto.Hash.Whirlpool Crypto.MAC Crypto.MAC.HMAC Crypto.MAC.SHA3

hidden-modules:       Crypto.Hash.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cryptohash-0.11.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cryptohash-0.11.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptohash
hs-libraries:         HScryptohash-0.11.9-K3a0fAHAiu2FHFicuGM3MM
depends:
    base-4.16.4.0 byteable-0.1.1-2aVcTelA6XA9YKIvhjRaxC
    bytestring-0.11.4.0 cryptonite-0.30-7YCFiEak3iS4jVbhqnIKep
    ghc-prim-0.8.0 memory-0.18.0-Hvum6HaH78UJG59LYyNLK1

haddock-interfaces:   /usr/share/doc/haskell-cryptohash/html/cryptohash.haddock
haddock-html:         /usr/share/doc/haskell-cryptohash/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-0.11.9-373.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cryptohash
version:              0.11.9
visibility:           public
id:                   cryptohash-0.11.9-AGPst9OJuj5EvR4kkNArqU
key:                  cryptohash-0.11.9-AGPst9OJuj5EvR4kkNArqU
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-cryptohash
synopsis:             collection of crypto hashes, fast, pure and practical
description:
    DEPRECATED: this library is still fully functional, but please use cryptonite for new projects
    and convert old one to use cryptonite. This is where things are at nowadays.

    A collection of crypto hashes, with a practical incremental and one-pass, pure APIs,
    with performance close to the fastest implementations available in other languages.

    The implementations are made in C with a haskell FFI wrapper that hide the C implementation.

    Simple examples using the unified API:

    > import Crypto.Hash
    >
    > sha1 :: ByteString -> Digest SHA1
    > sha1 = hash
    >
    > hexSha3_512 :: ByteString -> String
    > hexSha3_512 bs = show (hash bs :: Digest SHA3_512)

    Simple examples using the module API:

    > import qualified Crypto.Hash.SHA1 as SHA1
    >
    > main = putStrLn $ show $ SHA1.hash (Data.ByteString.pack [0..255])

    > import qualified Crypto.Hash.SHA3 as SHA3
    >
    > main = putStrLn $ show $ digest
    >   where digest = SHA3.finalize ctx
    >         ctx    = foldl'\'' SHA3.update iCtx (map Data.ByteString.pack [ [1,2,3], [4,5,6] ]
    >         iCtx   = SHA3.init 224

category:             Data, Cryptography
abi:                  453008ee7f8d9e8f1d91f52051b99628
exposed:              True
exposed-modules:
    Crypto.Hash Crypto.Hash.MD2 Crypto.Hash.MD4 Crypto.Hash.MD5
    Crypto.Hash.RIPEMD160 Crypto.Hash.SHA1 Crypto.Hash.SHA224
    Crypto.Hash.SHA256 Crypto.Hash.SHA3 Crypto.Hash.SHA384
    Crypto.Hash.SHA512 Crypto.Hash.SHA512t Crypto.Hash.Skein256
    Crypto.Hash.Skein512 Crypto.Hash.Tiger Crypto.Hash.Types
    Crypto.Hash.Whirlpool Crypto.MAC Crypto.MAC.HMAC Crypto.MAC.SHA3

hidden-modules:       Crypto.Hash.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cryptohash-0.11.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cryptohash-0.11.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cryptohash-0.11.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptohash
hs-libraries:         HScryptohash-0.11.9-AGPst9OJuj5EvR4kkNArqU
depends:
    base-4.17.2.1 byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY
    bytestring-0.11.5.3 cryptonite-0.30-1z5L2om720j2Q27zycLaKL
    ghc-prim-0.9.1 memory-0.18.0-1oHOZXUPjWrG0kImkORGvt

haddock-interfaces:   /usr/share/doc/haskell-cryptohash/html/cryptohash.haddock
haddock-html:         /usr/share/doc/haskell-cryptohash/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
